@echo off
:: TREAT Compatibility Setup Script for Windows 11
:: Ensures compatibility settings, installs required components, and checks dependencies

:: Step 0: Check for Administrative Privileges
net session >nul 2>&1
if %errorlevel% neq 0 (
    echo [ERROR] This script must be run as an administrator.
    echo Please right-click this file and select "Run as Administrator."
    pause
    exit /b 1
)

echo ========================================================
echo    TREAT Compatibility Setup for Windows 11
echo ========================================================
echo This script will configure your system to run TREAT smoothly.
echo Please wait while compatibility settings and dependencies are installed...
echo.

:: Step 1: Locate TREAT Installation
set TREAT_PATH=%ProgramFiles%\TREAT\TREAT.exe
if not exist "%TREAT_PATH%" (
    echo [ERROR] TREAT application not found in the default directory.
    echo Please ensure TREAT is installed or specify the correct path.
    pause
    exit /b 1
)

:: Step 2: Apply Compatibility Settings for TREAT
echo Configuring compatibility settings for TREAT...
REG ADD "HKCU\Software\Microsoft\Windows NT\CurrentVersion\AppCompatFlags\Layers" /v "%TREAT_PATH%" /t REG_SZ /d "WIN7RTM RUNASADMIN" /f
if %errorlevel% neq 0 (
    echo [ERROR] Could not apply compatibility settings.
    pause
    exit /b 1
)
echo [OK] Compatibility settings applied.

:: Step 3: Ensure .NET Framework 3.5 is Enabled
echo Checking if .NET Framework 3.5 is enabled...
Dism /online /Get-FeatureInfo /FeatureName:NetFx3 | findstr /C:"State : Enabled" >nul 2>&1
if %errorlevel% equ 0 (
    echo [OK] .NET Framework 3.5 is already enabled.
) else (
    echo .NET Framework 3.5 is not enabled. Attempting to enable it now...

    :: First, attempt online installation
    Dism /online /enable-feature /featurename:NetFx3 /All /Quiet /LimitAccess
    if %errorlevel% neq 0 (
        echo [WARNING] Online installation failed. Trying offline installation...

        :: Attempt offline installation (update the source path as needed)
        Dism /online /enable-feature /featurename:NetFx3 /All /Source:D:\sources\sxs /LimitAccess
        if %errorlevel% neq 0 (
            echo [ERROR] Failed to enable .NET Framework 3.5. Install it manually or use correct source files.
            pause
            exit /b 1
        )
    )
    echo [OK] .NET Framework 3.5 has been successfully enabled.
)

:: Step 4: Check and Download Visual C++ Redistributables
echo Checking for Visual C++ Redistributables...

:: Check for and download vc_redist.x86.exe if missing
if not exist "vc_redist.x86.exe" (
    echo vc_redist.x86.exe not found. Downloading...
    powershell -Command "Invoke-WebRequest -Uri 'https://aka.ms/vs/16/release/vc_redist.x86.exe' -OutFile 'vc_redist.x86.exe'"
    if %errorlevel% neq 0 (
        echo [ERROR] Failed to download vc_redist.x86.exe.
        pause
        exit /b 1
    )
)

:: Check for and download vc_redist.x64.exe if missing
if not exist "vc_redist.x64.exe" (
    echo vc_redist.x64.exe not found. Downloading...
    powershell -Command "Invoke-WebRequest -Uri 'https://aka.ms/vs/16/release/vc_redist.x64.exe' -OutFile 'vc_redist.x64.exe'"
    if %errorlevel% neq 0 (
        echo [ERROR] Failed to download vc_redist.x64.exe.
        pause
        exit /b 1
    )
)

:: Install Visual C++ Redistributables
echo Installing Visual C++ Redistributables...
start /wait vc_redist.x86.exe /quiet /norestart
start /wait vc_redist.x64.exe /quiet /norestart
echo [OK] Visual C++ Redistributables installed.

:: Step 5: Enable Legacy Components
echo Enabling legacy DirectPlay components (if required)...
Dism /online /enable-feature /featurename:DirectPlay /All /Quiet /LimitAccess
if %errorlevel% neq 0 (
    echo [ERROR] Could not enable legacy components. You may need to enable them manually.
    pause
    exit /b 1
)
echo [OK] Legacy components enabled.

:: Step 6: Verify Configuration
echo Verifying installation and configuration...
if exist "%TREAT_PATH%" (
    echo [OK] TREAT application detected.
) else (
    echo [ERROR] TREAT application not found. Ensure it is installed in the default directory.
    pause
    exit /b 1
)

echo.
echo ========================================================
echo    TREAT Compatibility Setup Complete!
echo ========================================================
echo You can now run TREAT with full compatibility on Windows 11.
pause
